pub struct SpannerDriver { /* private fields */ }Expand description
The Spanner ADBC driver — the entry point for creating SpannerDatabase instances.
The driver owns the shared Tokio runtime used to drive the asynchronous Spanner client, so a single driver instance should be reused for the lifetime of the application.
Implementations